#ifndef _ELM_MAP_PAN_EO_H_
#define _ELM_MAP_PAN_EO_H_

#ifndef _ELM_MAP_PAN_EO_CLASS_TYPE
#define _ELM_MAP_PAN_EO_CLASS_TYPE

typedef Eo Elm_Map_Pan;

#endif

#ifndef _ELM_MAP_PAN_EO_TYPES
#define _ELM_MAP_PAN_EO_TYPES


#endif
/** Elementary map pan class
 *
 * @ingroup Elm_Map_Pan
 */
#define ELM_MAP_PAN_CLASS elm_map_pan_class_get()

EWAPI const Efl_Class *elm_map_pan_class_get(void) EINA_CONST;

#endif
